Metas
=====

.. automodule:: epubaker.metas



Required Metadatas
------------------

.. autoclass:: Identifier
    :inherited-members:

.. autoclass:: Language
    :inherited-members:

.. autoclass:: Title
    :inherited-members:



Option Metadatas
----------------

.. autoclass:: Contributor
    :inherited-members:

.. autoclass:: Coverage
    :inherited-members:

.. autoclass:: Creator
    :inherited-members:

.. autoclass:: Date
    :inherited-members:

.. autoclass:: Description
    :inherited-members:

.. autoclass:: Format
    :inherited-members:

.. autoclass:: Publisher
    :inherited-members:

.. autoclass:: Relation
    :inherited-members:

.. autoclass:: Rights
    :inherited-members:

.. autoclass:: Source
    :inherited-members:

.. autoclass:: Subject
    :inherited-members:

.. autoclass:: Type
    :inherited-members:



Only for Epub3
--------------
.. autofunction:: get_dcterm

.. autoclass:: Meta3
    :inherited-members:



Only for Epub2
--------------
.. autoclass:: Meta2
    :inherited-members:

.. autoclass:: Cover
    :inherited-members:
